#include "form.h"
#include "ui_form.h"
#include "settings.h"
#include <QtGui>

Form::Form(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::Form)
{
//    mSettings.setValue("mem1Name", "Talk 1");
//    mSettings.setValue("mem1Value", 240);
//    mSettings.setValue("mem2Name", "Talk 2/3");
//    mSettings.setValue("mem2Value", 300);
//    mSettings.setValue("mem3Name", "Pasta");
//    mSettings.setValue("mem3Value", 360);

    //mSettings.sync();

    mvStarted = 0;
    mvCountDown = 0;

    ui->setupUi(this);
    mvpTimer = new QTimer(this);
    connect(mvpTimer, SIGNAL(timeout()), this, SLOT(update()));

    syncSettings();
}

Form::~Form()
{
    delete mvpTimer;
    delete ui;
}

void Form::syncSettings()
{
    ui->pushButton_mem_1->setText(mSettings.value("mem1Name").toString());
    ui->pushButton_mem_2->setText(mSettings.value("mem2Name").toString());
    ui->pushButton_mem_3->setText(mSettings.value("mem3Name").toString());
    ui->pushButton_mem_4->setText(mSettings.value("mem4Name").toString());
}

void Form::changeEvent(QEvent *e)
{
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void Form::update()
{
    int timerSeconds = mvCountDown - mvTime.elapsed() / 1000;

    if (timerSeconds <= 0) {
        mvpTimer->stop();
        mvCountDown = 0;
        QSound::play("/sounds/bell_ting_ting.wav");
        ui->pushButton_start->setText("Start");
        mvStarted = 0;
    }

    formatTimer(timerSeconds);
}

void Form::formatTimer(int timerSeconds)
{
    QString text;
    text.sprintf("%02d:%02d", timerSeconds / 60, timerSeconds % 60);
    ui->label->setText(text);
}

void Form::setTimer(int timerSeconds)
{
    mvpTimer->stop();
    mvCountDown = timerSeconds;
    formatTimer(mvCountDown);
    ui->pushButton_start->setText("Start");
    mvStarted = 0;
}

void Form::changeTimer(bool addTime, int amountSeconds)
{
    if (mvStarted != 1) {

        if (addTime) {
            mvCountDown += amountSeconds;
        } else {
            mvCountDown -= amountSeconds;
        }

        if (mvCountDown <= 0) {
            mvCountDown = 0;
        } else if (mvCountDown >= 3600) {
            mvCountDown = 3600;
        }

        formatTimer(mvCountDown);
    }
}

void Form::on_pushButton_start_clicked()
{

    switch (mvStarted) {
    case 0:
        mvTime.start();
        update();
        mvpTimer->start(100);
        ui->pushButton_start->setText("Stop");
        mvStarted = 1;
        break;
    case 1:
        mvpTimer->stop();
        update();
        mvCountDown -= mvTime.elapsed() / 1000;
        ui->pushButton_start->setText("Continue");
        mvStarted = 2;
        break;
    case 2:
        mvTime.restart();
        mvpTimer->start(100);
        update();
        ui->pushButton_start->setText("Stop");
        mvStarted = 1;
        break;
    }
        //QSound::play("whip1.wav");
}

void Form::on_pushButton_reset_clicked()
{
   setTimer(0);
}

void Form::on_pushButton_seconds_plus_clicked()
{
    changeTimer(true, 1);
}

void Form::on_pushButton_seconds_minus_clicked()
{
    changeTimer(false, 1);
}

void Form::on_pushButton_minutes_plus_clicked()
{
    changeTimer(true, 60);
}

void Form::on_pushButton_minutes_minus_clicked()
{
    changeTimer(false, 60);
}

void Form::on_pushButton_mem_1_clicked()
{
    setTimer(mSettings.value("mem1Value").toInt());
}

void Form::on_pushButton_mem_2_clicked()
{
    setTimer(mSettings.value("mem2Value").toInt());
}

void Form::on_pushButton_mem_3_clicked()
{
    setTimer(mSettings.value("mem3Value").toInt());
}

void Form::on_pushButton_mem_4_clicked()
{
    setTimer(mSettings.value("mem4Value").toInt());
}

void Form::on_pushButton_settings_clicked()
{
    settingsDialog = new Settings;
    settingsDialog->exec();
    syncSettings();
}
